@@ -1,21 +1,12 @@
-import click
 import logging
 
+import click
+
 from pypgatk.commands.utils import print_help
 from pypgatk.ensembl.ensembl import EnsemblDataService
-
-import pkgutil
-
-from pypgatk.toolbox.general import read_yaml_from_text, read_yaml_from_file
+from pypgatk.toolbox.general import read_yaml_from_file
 
 log = logging.getLogger(__name__)
-try:
-    default_config_text = pkgutil.get_data(__name__, "../config/ensembl_config.yaml").decode()
-except ValueError:
-    try:
-        default_config_text = pkgutil.get_data(__name__, "config/ensembl_config.yaml").decode()
-    except ValueError:
-        log.info("Configuration file not available !!! ")
 
 
 @click.command('ensembl-check', short_help="Command to check ensembl database for stop codons, gaps")
@@ -30,17 +21,14 @@ except ValueError:
 @click.pass_context
 def ensembl_check(ctx, config_file, input_fasta, output, add_stop_codons, num_aa):
 
-  if config_file is None:
-    config_data = read_yaml_from_text(default_config_text)
-    msg = "The default configuration file is used: {}".format("ensembl_config.yaml")
-    log.info(msg)
-  else:
-    config_data = read_yaml_from_file(config_file)
+    config_data = None
+    if config_file is not None:
+        config_data = read_yaml_from_file(config_file)
 
-  if input_fasta is None:
-    print_help()
+    if input_fasta is None:
+        print_help()
 
-  pipeline_arguments = {EnsemblDataService.PROTEIN_DB_OUTPUT: output}
+    pipeline_arguments = {EnsemblDataService.PROTEIN_DB_OUTPUT: output}
 
-  ensembl_data_service = EnsemblDataService(config_data, pipeline_arguments)
-  ensembl_data_service.check_proteindb(input_fasta, add_stop_codons, num_aa)
+    ensembl_data_service = EnsemblDataService(config_data, pipeline_arguments)
+    ensembl_data_service.check_proteindb(input_fasta, add_stop_codons, num_aa)
