@@ -1,21 +1,13 @@
 import logging
+
 import click
 
+from pypgatk.commands.utils import print_help
 from pypgatk.proteomics.db.protein_database_decoy import ProteinDBDecoyService
 from pypgatk.proteomics.models import PYGPATK_ENZYMES
-import pkgutil
-
-from pypgatk.toolbox.general import read_yaml_from_text, read_yaml_from_file
+from pypgatk.toolbox.general import read_yaml_from_file
 
 log = logging.getLogger(__name__)
-try:
-  default_config_text = pkgutil.get_data(__name__, "../config/protein_decoy.yaml").decode()
-except ValueError:
-    try:
-        default_config_text = pkgutil.get_data(__name__, "config/protein_decoy.yaml").decode()
-    except ValueError:
-        log.info("Configuration file not available !!! ")
-
 
 
 @click.command('generate-decoy',
@@ -58,67 +50,63 @@ def generate_database(ctx, config_file: str, output_database: str, input_databas
                       max_missed_cleavages: int, min_peptide_length: int, max_peptide_length: int,
                       max_iterations: int, do_not_shuffle: bool, do_not_switch: bool, temp_file: str,
                       no_isobaric: bool, keep_target_hits: bool, memory_save: bool):
+    config_data = None
+    if config_file is not None:
+        config_data = read_yaml_from_file(config_file)
 
-  if config_file is None:
-    config_data = read_yaml_from_text(default_config_text)
-    msg = "The default configuration file is used: {}".format("protein_decoy.yaml")
-    log.info(msg)
-  else:
-    config_data = read_yaml_from_file(config_file)
+    pipeline_arguments = {}
 
-  pipeline_arguments = {}
+    if input_database is None:
+        print_help()
 
-  if input_database is None:
-    help(ctx)
+    if output_database is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_PROTEINDB_OUTPUT] = output_database
 
-  if output_database is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_PROTEINDB_OUTPUT] = output_database
+    if input_database is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_INPUT_FILE] = input_database
 
-  if input_database is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_INPUT_FILE] = input_database
+    if method is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_DECOY_METHOD] = method
 
-  if method is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_DECOY_METHOD] = method
+    if enzyme is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_ENZYME] = enzyme
 
-  if enzyme is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_ENZYME] = enzyme
+    if cleavage_position is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_CLEAVAGE_POSITION] = cleavage_position
 
-  if cleavage_position is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_CLEAVAGE_POSITION] = cleavage_position
+    if max_missed_cleavages is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_MAX_MISSED_CLEAVAGES] = max_missed_cleavages
 
-  if max_missed_cleavages is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_MAX_MISSED_CLEAVAGES] = max_missed_cleavages
+    if min_peptide_length is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_MIN_PEPTIDE_LENGTH] = min_peptide_length
 
-  if min_peptide_length is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_MIN_PEPTIDE_LENGTH] = min_peptide_length
+    if max_peptide_length is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_PEPTIDE_LENGTH_MAX] = max_peptide_length
 
-  if max_peptide_length is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_PEPTIDE_LENGTH_MAX] = max_peptide_length
+    if max_iterations is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_MAX_ITERATIONS] = max_iterations
 
-  if max_iterations is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_MAX_ITERATIONS] = max_iterations
+    if do_not_shuffle is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_DO_NOT_SUFFLE] = do_not_shuffle
 
-  if do_not_shuffle is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_DO_NOT_SUFFLE] = do_not_shuffle
+    if do_not_switch is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_DO_NOT_SWITCH] = do_not_switch
 
-  if do_not_switch is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_DO_NOT_SWITCH] = do_not_switch
+    if decoy_prefix is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_DECOY_PREFIX] = decoy_prefix
 
-  if decoy_prefix is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_DECOY_PREFIX] = decoy_prefix
+    if temp_file is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_TEMP_FILE] = temp_file
 
-  if temp_file is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_TEMP_FILE] = temp_file
+    if no_isobaric is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_NO_ISOBARIC] = no_isobaric
 
-  if no_isobaric is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_NO_ISOBARIC] = no_isobaric
+    if keep_target_hits is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_KEEP_TARGET_HITS] = keep_target_hits
 
-  if keep_target_hits is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_KEEP_TARGET_HITS] = keep_target_hits
+    if memory_save is not None:
+        pipeline_arguments[ProteinDBDecoyService.CONFIG_MEMORY_SAVE] = memory_save
 
-  if memory_save is not None:
-    pipeline_arguments[ProteinDBDecoyService.CONFIG_MEMORY_SAVE] = memory_save
-
-  proteindb_decoy = ProteinDBDecoyService(config_data, pipeline_arguments)
-  proteindb_decoy.decoy_database()
-  proteindb_decoy.print_target_decoy_composition()
+    proteindb_decoy = ProteinDBDecoyService(config_data, pipeline_arguments)
+    proteindb_decoy.decoy_database()
+    proteindb_decoy.print_target_decoy_composition()
